@@ -12,7 +12,7 @@
 #' data(car)
 #' nb <- nb('class', car)   
 #' nb2 <- nb('class', features = letters[1:10])
-#' plot(nb2)
+#' \dontrun{plot(nb2)}
 nb <- function(class, dataset = NULL, features = NULL) {
   #   # if dataset is provided features is ignored
   if (!is.null(dataset)) {
@@ -57,8 +57,21 @@ tan_hc <- function(class, dataset, k, epsilon = 0.01, smooth = 0,
                 smooth = smooth, cache_reset = cache_reset)
   add_dag_call_arg(x, fun_name = 'tan_hc', call = match.call(), 
                    env = parent.frame(), force = TRUE)
+} 
+#' @export
+#' @rdname greedy_wrapper
+kdb <- function(class, dataset, k, kdbk = 2, epsilon = 0.01, smooth = 0,
+                   cache_reset = NULL) {    
+  full_nb <- nb(class = class, dataset)
+  full_nb <- remove_dag_call_arg(full_nb)
+  x <- greedy_search(class = class, to_include = NULL, init = full_nb,
+                step = augment_kdb(kdbk), dataset = dataset, epsilon = epsilon, k = k,
+                smooth = smooth, cache_reset = cache_reset)
+  add_dag_call_arg(x, fun_name = 'kdb', call = match.call(), 
+                   env = parent.frame(), force = TRUE)
 }
 #' @export
+#' @export
 #' @rdname greedy_wrapper
 tan_hcsp <- function(class, dataset, k, epsilon = 0.01, smooth = 0,
                      cache_reset = NULL) {    
@@ -77,4 +90,22 @@ tan_cl <- function(class, dataset, score='loglik', root = NULL) {
           root = root)
   add_dag_call_arg(x, fun_name = 'tan_cl', call = match.call(), 
                    env = parent.frame(), force = TRUE)
-}
\ No newline at end of file
+}
+#' Learn an AODE ensemble.
+#' 
+#' If there is a single predictor then returns a naive Bayes.
+#' 
+#' @export
+#' @inheritParams nb
+#' @return A \code{bnc_aode} or a \code{bnc_dag} (if returning a naive Bayes)
+aode <- function(class, dataset, features = NULL) {       
+  if (!is.null(dataset)) {
+    features <- get_features(class = class, dataset = dataset)
+  }
+  if (length(features) == 1) return(nb(class = class, features = features))
+  names(features) <- features
+  models <- lapply(features, spode, features, class)
+  x <- bnc_aode(models = models, class_var = class, features = features) 
+  add_dag_call_arg(x, fun_name = 'aode', call = match.call(), 
+                   env = parent.frame(), force = TRUE)
+}  
\ No newline at end of file
