@@ -109,11 +109,8 @@ test_that("correct cv result with missing data", {
   nb <- nbvote() 
   suppressWarnings(RNGversion("3.5.0"))
   set.seed(0) 
-  # gRain implementation change
-  # s <- cv(nb, voting, k = 5, dag = TRUE)
-  # expect_equal(s, 0.9014301, tolerance = 1e-6)   
-  # gRain implementation change
-  expect_error(s <- cv(nb, voting, k = 5, dag = TRUE))
+  s <- cv(nb, voting, k = 5, dag = TRUE)
+  expect_equal(s, 0.9014301, tolerance = 1e-6)
 })
 
 test_that("cv with just-class classifier", {
