@@ -146,4 +146,15 @@ test_that("augment ode hc nominal", {
   mem <- make_cpts_cache(car, smooth = 0.01)
   a <- augment_ode_sp(nb, NULL, train = list(mem, mem), test = list(car, car))
   expect_equal(length(a), 5)  
-})
\ No newline at end of file
+})
+  
+test_that("Discard existing", {
+  nb <- nbcarp(car) 
+  arcs <- arcs_to_orphans(features(nb), character()) 
+  d <- discard_existing(arcs, nb)
+  expect_equal(nrow(d), nrow(arcs))
+  
+  nb <- add_feature_parents('lug_boot', 'safety', nb)  
+  d <- discard_existing(arcs, nb)
+  expect_equal(nrow(d), nrow(arcs) - 1) 
+}) 
\ No newline at end of file
